==> wiki3_4_3.zip: wiki3_4_3/plugin/admin/AdminPageHandler.pm <==
###############################################################################
#
# ڡ⥸塼
#
###############################################################################
package plugin::admin::AdminPageHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	my $login = $wiki->get_login_info();
	
	if($cgi->param("freeze") ne ""){
		$self->freeze_page($wiki);
		
	} elsif($cgi->param("unfreeze") ne ""){
		$self->unfreeze_page($wiki);
		
	} elsif($cgi->param("delete") ne ""){
		$self->delete_page($wiki);
	}
	return $self->page_list($wiki);
}

#==============================================================================
# ڡκ
#==============================================================================
sub delete_page {
	my $self = shift;
	my $wiki = shift;
	
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->save_page($_,"");
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub freeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 1;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 0;
				last;
			}
		}
		if($flag){
			$wiki->freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub unfreeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 1;
				last;
			}
		}
		if($flag){
			$wiki->un_freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub page_list {
	my $self = shift;
	my $wiki = shift;
	
	my @freeze_list = $wiki->get_freeze_list();
	my @pages = $wiki->get_page_list();
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "<table>\n".
	          "<tr>\n".
	          "  <th><br></th>\n".
	          "  <th></th>\n".
#	          "  <th>ź</th>\n".
	          "  <th>ڡ̾</th>\n".
	          "  <th>ǽ</th>\n".
	          "</tr>\n";
	
	foreach my $page (@pages){
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"pages\" value=\"".&Util::escapeHTML($page)."\"></td>\n";
		
		# 뤵Ƥ뤫Ĵ٤
		my $is_freeze = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$is_freeze = 1;
				last;
			}
		}
		if($is_freeze){
			$buf .= "  <td align=\"center\"></td>\n";
		} else {
			$buf .= "  <td><br></td>\n";
		}
		
		$buf .= "  <td><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($page)."\">".&Util::escapeHTML($page)."</a></td>\n".
		        "  <td>".&Util::format_date($wiki->get_last_modified($page))."</td>\n".
		        "</tr>\n";
	}
	$buf .= "</table>\n".
	        "<br>\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINPAGE\">\n".
	        "<input type=\"submit\" name=\"freeze\" value=\"   \">\n".
	        "<input type=\"submit\" name=\"unfreeze\" value=\"\">\n".
	        "<input type=\"submit\" name=\"delete\" value=\"   \">\n".
	        "</form>\n";
	
	$wiki->set_title("ڡδ");
	return $buf."</ul>\n";
}

1;

==> wiki3_5_1.zip: wiki3_5_1/plugin/admin/AdminPageHandler.pm <==
###############################################################################
#
# ڡ⥸塼
#
###############################################################################
package plugin::admin::AdminPageHandler;
#use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self = {};
	
	# ե륿¸ե
	$self->{filter_file} = "filter.dat";
	
	return bless $self,$class;
}

#==============================================================================
# ϥɥ᥽å
#==============================================================================
sub do_action {
	my $self  = shift;
	my $wiki  = shift;
	my $cgi   = $wiki->get_CGI;
	my $login = $wiki->get_login_info();
	
	if($cgi->param("freeze") ne ""){
		$self->freeze_page($wiki);
		
	} elsif($cgi->param("unfreeze") ne ""){
		$self->unfreeze_page($wiki);
		
	} elsif($cgi->param("delete") ne ""){
		$self->delete_page($wiki);
		
	} elsif($cgi->param("show_all") ne ""){
		$self->show_all($wiki);
		
	} elsif($cgi->param("show_user") ne ""){
		$self->show_user($wiki);
		
	} elsif($cgi->param("show_admin") ne ""){
		$self->show_admin($wiki);
		
	}
	return $self->page_list($wiki);
}

#==============================================================================
# ڡκ
#==============================================================================
sub delete_page {
	my $self = shift;
	my $wiki = shift;
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->save_page($_,"");
	}
}

#==============================================================================
# ˸
#==============================================================================
sub show_all {
	my $self = shift;
	my $wiki = shift;
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->set_page_level($_,0);
	}
}

#==============================================================================
# 桼Τ߻Ȳǽ
#==============================================================================
sub show_user {
	my $self = shift;
	my $wiki = shift;
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->set_page_level($_,1);
	}
}

#==============================================================================
# ԤΤ߻Ȳǽ
#==============================================================================
sub show_admin {
	my $self = shift;
	my $wiki = shift;
	my @pages = $wiki->get_CGI->param("pages");
	foreach(@pages){
		$wiki->set_page_level($_,2);
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub freeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 1;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 0;
				last;
			}
		}
		if($flag){
			$wiki->freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub unfreeze_page {
	my $self = shift;
	my $wiki = shift;
	my @freeze_list = $wiki->get_freeze_list;
	my @pages = $wiki->get_CGI->param("pages");
	foreach my $page (@pages){
		my $flag = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$flag = 1;
				last;
			}
		}
		if($flag){
			$wiki->un_freeze_page($page);
		}
	}
}

#==============================================================================
# ڡ
#==============================================================================
sub page_list {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI();
	
	my @freeze_list = $wiki->get_freeze_list();
	my @pages       = $wiki->get_page_list();
	my $level_list  = $wiki->get_page_level();
	my $filter = $cgi->param("filter");
	
	# ե륿¸ѥ᡼ǻꤵƤʤɤ߹ߡ
	if(defined($filter)){
		&Util::save_config_text($wiki,$self->{filter_file},$filter);
	} else {
		$filter = &Util::load_config_text($wiki,$self->{filter_file});
	}
	
	my $buf = "<h2>ڡ</h2>\n".
	          "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "ե륿ɽѲǽ\n".
	          "<input type=\"text\" name=\"filter\" size=\"30\" value=\"".Util::escapeHTML($filter)."\">\n".
	          "<input type=\"submit\" value=\"ɽ\">\n".
	          "<br /><br />\n".
	          "<table>\n".
	          "<tr>\n".
	          "  <th><br></th>\n".
	          "  <th></th>\n".
	          "  <th></th>\n".
	          "  <th width=\"200\">ڡ̾</th>\n".
	          "  <th>ǽ</th>\n".
	          "</tr>\n";
	
	# / 򥨥
	$filter =~ s|/|\\/|g;
	
	foreach my $page (@pages){
		if($filter ne ""){
			# 㤦⤷ʤΤeval
			unless(eval( '$page =~ /'.$filter.'/')){
				next;
			}
		}
		$buf .= "<tr>\n".
		        "  <td><input type=\"checkbox\" name=\"pages\" value=\"".&Util::escapeHTML($page)."\"></td>\n";
		
		# 뤵Ƥ뤫Ĵ٤
		my $is_freeze = 0;
		foreach(@freeze_list){
			if($_ eq $page){
				$is_freeze = 1;
				last;
			}
		}
		if($is_freeze){
			$buf .= "  <td align=\"center\"></td>\n";
		} else {
			$buf .= "  <td><br></td>\n";
		}
		
		# ȥ٥Ĵ٤
		if(!defined($level_list->{$page}) || $level_list->{$page}==0){
			$buf .= "  <td></td>\n";
		} elsif($level_list->{$page}==1){
			$buf .= "  <td>桼</td>\n";
		} elsif($level_list->{$page}==2){
			$buf .= "  <td></td>\n";
		}
		
		$buf .= "  <td><a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($page)."\">".&Util::escapeHTML($page)."</a></td>\n".
		        "  <td>".&Util::format_date($wiki->get_last_modified($page))."</td>\n".
		        "</tr>\n";
	}
	
	$buf .= "</table>\n".
	        "<br>\n".
	        "<input type=\"hidden\" name=\"action\" value=\"ADMINPAGE\">\n".
	        "<h3>ڡ</h3>\n".
	        "<p>åڡ뤷ޤ뤷ڡϥΤԽȤʤޤ</p>\n".
	        "<input type=\"submit\" name=\"freeze\" value=\"   \">\n".
	        "<input type=\"submit\" name=\"unfreeze\" value=\"\">\n".
	        "<h3>ڡκ</h3>\n".
	        "<p>åڡޤ</p>\n".
	        "<input type=\"submit\" name=\"delete\" value=\"   \">\n".
	        "<h3>ȸ¤</h3>\n".
	        "<p>åڡλȸ¤ꤷޤ</p>\n".
	        "<input type=\"submit\" name=\"show_all\"   value=\"   \">\n".
	        "<input type=\"submit\" name=\"show_user\"  value=\"桼Τ\">\n".
	        "<input type=\"submit\" name=\"show_admin\" value=\"ԤΤ\">\n".
	        "</form>\n";
	
	$wiki->set_title("ڡδ");
	return $buf."</ul>\n";
}

1;
